@@ -23,7 +23,7 @@ class Table(object):
     result = s3_client.list_objects_v2(Bucket=self.database.name, Prefix=os.path.join(self.name, key))
     contents = result.get("Contents")
     if contents is None:
-      return
+      return []
     return [content['Key'][len(self.name)+1:] for content in contents if content.get('Key')]
 
   def select_by_key(self, key) -> bytes:
@@ -52,6 +52,10 @@ class Table(object):
     key = column_placeholder.format(**kwargs)
     return self.select_by_key(key)
 
+  def select_string(self, **kwargs) -> str:
+    data = self.select(**kwargs)
+    return data.decode("utf8")
+
   def insert(self, **kwargs):
     if not self.columns:
       raise Exception("Columns not set. Please set columns before using this method")
@@ -66,6 +70,13 @@ class Table(object):
     key = column_placeholder.format(**kwargs)
     return self.insert_by_key(key, data)
 
+  def insert_string(self, **kwargs):
+    if kwargs.get("data") is None:
+      raise Exception("data not found. You must include something to insert")
+    data = kwargs["data"]
+    kwargs["data"] = data.encode("utf8")
+    return self.insert(**kwargs)
+
   def delete(self, **kwargs):
     if not self.columns:
       raise Exception("Columns not set. Please set columns before using this method")
